summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmboxedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmboxedit.h')
-rw-r--r--kpovmodeler/pmboxedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmboxedit.h b/kpovmodeler/pmboxedit.h
index f9f0bf6d..9368bfbd 100644
--- a/kpovmodeler/pmboxedit.h
+++ b/kpovmodeler/pmboxedit.h
@@ -39,9 +39,9 @@ class PMBoxEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMBoxEdit with tqparent and name
*/
- PMBoxEdit( TQWidget* tqparent, const char* name = 0 );
+ PMBoxEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMBoxEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMBoxEdit with tqparent and name
+ * Creates a PMBoxEdit with parent and name
*/